<div class="header">
<?php MenuFormlet::show() ?>
<?php if (WebSession::isLogined()): ?>
  <?php ToolbarFormlet::show() ?>
<?php endif; ?>
</div>

<h1><?php echo htmlspecialchars(SITE_NAME) ?> - <?php echo htmlspecialchars(SITE_SUBTITLE) ?></h1>

<?php
$formatter = new Formatter();

if (WebSession::isLogined()):
  echo "<p>", $formatter->format(WikiPageStorage::get(WELCOME_USERS)), "</p>";
  FormletShowFormlet::show();
else:
  echo "<p>", $formatter->format(WikiPageStorage::get(WELCOME_VISITORS)), "</p>";
  include "template/RecentList.tmpl.php";
?>
 <h2>Ͽ桼̾</h2>
 <?php AccountListFormlet::show() ?>
<?php
endif;
?>
